@@ -323,12 +323,12 @@ class Install(install_misc.InstallBase):
         cache = Cache()
 
         # Python standard library.
-        re_minimal = re.compile('^python\d+\.\d+-minimal$')
+        re_minimal = re.compile(r'^python\d+\.\d+-minimal$')
         python_installed = sorted([
             pkg[:-8] for pkg in cache.keys()
             if re_minimal.match(pkg) and cache[pkg].is_installed])
         for python in python_installed:
-            re_file = re.compile('^/usr/lib/%s/.*\.py$' % python)
+            re_file = re.compile(r'^/usr/lib/%s/.*\.py$' % python)
             files = [
                 f for f in cache['%s-minimal' % python].installed_files
                 if (re_file.match(f) and
@@ -831,10 +831,6 @@ class Install(install_misc.InstallBase):
                     'ssl-cert']
         arch, subarch = install_misc.archdetect()
 
-        # this postinst installs EFI application and cleans old entries
-        if arch in ('amd64', 'i386') and subarch == 'efi':
-            packages.append('fwupdate')
-
         try:
             for package in packages:
                 install_misc.reconfigure(self.target, package)
@@ -1149,12 +1145,13 @@ class Install(install_misc.InstallBase):
             self.verify_language_packs()
 
     def install_restricted_extras(self):
+        packages = []
         if self.db.get('ubiquity/use_nonfree') == 'true':
             self.db.progress('INFO', 'ubiquity/install/nonfree')
-            packages = self.db.get('ubiquity/nonfree_package').split()
-            # also install recorded non-free packages
-            packages.extend(install_misc.query_recorded_installed())
-            self.do_install(packages)
+            packages.extend(self.db.get('ubiquity/nonfree_package').split())
+        # also install recorded non-free packages
+        packages.extend(install_misc.query_recorded_installed())
+        self.do_install(packages)
 
     def install_extras(self):
         """Try to install packages requested by installer components."""
@@ -1406,7 +1403,7 @@ class Install(install_misc.InstallBase):
         arch, subarch = install_misc.archdetect()
 
         if arch in ('amd64', 'i386'):
-            for pkg in ('grub', 'grub-pc', 'grub-efi', 'grub-efi-amd64',
+            for pkg in ('grub', 'grub-efi', 'grub-efi-amd64',
                         'grub-efi-amd64-signed', 'shim-signed', 'mokutil',
                         'lilo'):
                 if pkg not in keep:
