@@ -231,6 +231,8 @@ class Wizard(BaseFrontend):
         self.progress_cancelled = False
         self.installing = False
         self.installing_no_return = False
+        self.partitioned = False
+        self.timezone_set = False
         self.returncode = 0
         self.history = []
         self.builder = Gtk.Builder()
@@ -585,6 +587,29 @@ class Wizard(BaseFrontend):
 
         gsettings.set(gs_schema, gs_key, gs_value)
 
+    def disable_screen_blanking(self):
+        gs_schema = 'org.gnome.desktop.session'
+        gs_key = 'idle-delay'
+        gs_previous = '%s/%s' % (gs_schema, gs_key)
+        if gs_previous in self.gsettings_previous:
+            return
+
+        gs_value = gsettings.get(gs_schema, gs_key)
+        self.gsettings_previous[gs_previous] = gs_value
+
+        if gs_value:
+            gsettings.set(gs_schema, gs_key, 0)
+
+        atexit.register(self.enable_screen_blanking)
+
+    def enable_screen_blanking(self):
+        gs_schema = 'org.gnome.desktop.session'
+        gs_key = 'idle-delay'
+        gs_previous = '%s/%s' % (gs_schema, gs_key)
+        gs_value = self.gsettings_previous[gs_previous]
+
+        gsettings.set(gs_schema, gs_key, gs_value)
+
     def disable_powermgr(self):
         gs_schema = 'org.gnome.settings-daemon.plugins.power'
         gs_key = 'active'
@@ -736,6 +761,7 @@ class Wizard(BaseFrontend):
 
         self.disable_volume_manager()
         self.disable_screensaver()
+        self.disable_screen_blanking()
         self.disable_powermgr()
 
         if 'UBIQUITY_ONLY' in os.environ:
@@ -1349,7 +1375,8 @@ class Wizard(BaseFrontend):
 
         if self.pagesindex == 0:
             self.allow_go_backward(False)
-        elif self.pages[self.pagesindex - 1].module.NAME == 'partman':
+        elif 'partman' in [page.module.NAME for page in
+                           self.pages[:self.pagesindex - 1]]:
             # We're past partitioning.  Unless the install fails, there is no
             # going back.
             self.allow_go_backward(False)
@@ -1634,6 +1661,29 @@ class Wizard(BaseFrontend):
         self.installing = True
         self.lockdown_environment()
 
+    def maybe_start_installing(self):
+        if not (self.partitioned and self.timezone_set):
+            syslog.syslog(
+                'Not installing yet, partitioned: %s, timezone_set %s' %
+                (self.partitioned, self.timezone_set))
+            return
+
+        syslog.syslog('Starting the installation')
+
+        from ubiquity.debconfcommunicator import DebconfCommunicator
+        if self.parallel_db is not None:
+            self.parallel_db.shutdown()
+        env = os.environ.copy()
+        # debconf-apt-progress, start_debconf()
+        env['DEBCONF_DB_REPLACE'] = 'configdb'
+        env['DEBCONF_DB_OVERRIDE'] = 'Pipe{infd:none outfd:none}'
+        self.parallel_db = DebconfCommunicator('ubiquity',
+                                               cloexec=True,
+                                               env=env)
+        # Start the actual install
+        dbfilter = install.Install(self, db=self.parallel_db)
+        dbfilter.start(auto_process=True)
+
     def find_next_step(self, finished_step):
         # TODO need to handle the case where debconffilters launched from
         # here crash.  Factor code out of dbfilter_handle_status.
@@ -1673,11 +1723,19 @@ class Wizard(BaseFrontend):
             dbfilter = partman_commit.PartmanCommit(self, db=self.parallel_db)
             dbfilter.start(auto_process=True)
 
-        # FIXME OH DEAR LORD.  Use isinstance.
-        elif finished_step == 'ubiquity.components.partman_commit':
-            dbfilter = install.Install(self, db=self.parallel_db)
-            dbfilter.start(auto_process=True)
+        elif finished_step == 'ubi-timezone':
+            self.timezone_set = True
+            # Flush changes to the database so that when the parallel db
+            # starts, it does so with the most recent changes.
+            self.stop_debconf()
+            self.start_debconf()
+            self.maybe_start_installing()
 
+        elif finished_step == 'ubiquity.components.partman_commit':
+            self.partitioned = True
+            self.maybe_start_installing()
+
+        # FIXME OH DEAR LORD.  Use isinstance.
         elif finished_step == 'ubiquity.components.install':
             self.finished_installing = True
             if self.finished_pages:
